@@ -28,6 +28,7 @@ from scrapy.pipelines.files import FileException, FilesPipeline
 
 import oss2
 import magic
+import requests
 
 import pdfplumber
 from PyPDF2 import PdfFileReader, PdfFileWriter
@@ -169,7 +170,7 @@ class OssFilesPipeline(MediaPipeline):
             #invalid_file_body
             'FILTER_INVALID_FILE_PATH', False
         )
-        self.page_logo_text = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('PAGE_LOGO_TEXT',None)
+        self.page_logo_text = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('PAGE_LOGO_TEXT','')
         self.item_header_dict = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('ITEM_HEADER',None)
         self.files_oss_file = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('FILES_OSS_FILE')
         self.if_feed = settings.get('FEEDS').attributes 
@@ -209,12 +210,6 @@ class OssFilesPipeline(MediaPipeline):
 
     def media_downloaded(self, response, request, info, *, item=None): # 判断是否正常资源
         referer = referer_str(request)
-        if self.invalid_fild_path:
-            # invalid_fild_path :: 失效文件路径,表示遇到该文件结果字段如pdf_url就返回空
-            with open(f"{self.invalid_fild_path}",'rb') as f:
-                invalid_file_body = f.read()
-            if invalid_file_body == response.body:
-                return {'url': request.url, 'path': ''}
         if response.status != 200:
             logger.warning(
                 'File (code: %(status)s): Error downloading file from '
@@ -225,6 +220,28 @@ class OssFilesPipeline(MediaPipeline):
             )
             raise FileException('download-error')
 
+        if magic.from_buffer(response.body, mime=True).split('/')[-1] == 'pdf':
+            for i in range(3):
+                # 如果pdf损坏重试
+                try:
+                    reader = PdfFileReader(io.BytesIO(response.body))
+                    if reader.getNumPages() < 1:    #进一步通过页数判断。
+                        raise FileException('文件损坏,requests库重试')
+                    else:
+                        break
+                except:
+                    headers = Headers(response.request.headers).to_unicode_dict()
+                    contents = requests.get(response.request.url,headers = headers).content
+                    response.replace(body=contents)
+                    logging.info(f"Retry {i+1} times , Url is {response.request.url}")
+
+        if self.invalid_fild_path:
+            # invalid_fild_path :: 失效文件路径,表示遇到该文件结果字段如pdf_url就返回空
+            with open(f"{self.invalid_fild_path}",'rb') as f:
+                invalid_file_body = f.read()
+            if invalid_file_body == response.body:
+                return {'url': request.url, 'path': ''}
+
         if not response.body:
             logger.warning(
                 'File (empty-content): Empty file from %(request)s referred '
@@ -364,7 +381,7 @@ class OssFilesPipelineDatasheet(OssFilesPipeline):
     def media_downloaded(self, response, request, info, *, item=None):  # 判断是否正常资源
         referer = referer_str(request)
         # if response.status == 200:
-        with pdfplumber.load(io.BytesIO(response.body)) as pdf:
+        with pdfplumber.open(io.BytesIO(response.body)) as pdf:
             last_page = pdf.pages[0]
             first_page_txt = last_page.extract_text()
             if self.page_logo_text in first_page_txt and self.page_logo_text:
