@@ -340,7 +340,8 @@ class ItemHeadersMiddleware:
                 headers = response.request.headers.copy()
                 if response.headers.get('Set-Cookie'):
                     # 取上层cookie以及setcookie重组
-                    cookie =  headers.get('cookie','').decode("utf-8")+'; '+';'.join(i.decode("utf-8") for i in response.headers.getlist('Set-Cookie'))
+                    cur_cookie = headers.get('cookie','').decode("utf-8")+ '; ' if headers.get('cookie','').decode("utf-8") else ''
+                    cookie =  cur_cookie +';'.join(i.decode("utf-8") for i in response.headers.getlist('Set-Cookie'))
                     headers['Cookie'] = cookie
                 if '_refer' not in r.__dict__:
                     r.__setattr__('_refer',referrer)
